"use strict";
exports.__esModule = true;
var Boom = require("boom");
var GraphiQL = require("apollo-server-module-graphiql");
var apollo_server_core_1 = require("apollo-server-core");
if (typeof Object.assign != 'function') {
    Object.assign = function (target) {
        'use strict';
        if (target == null) {
            throw new TypeError('Cannot convert undefined or null to object');
        }
        target = Object(target);
        for (var index = 1; index < arguments.length; index++) {
            var source = arguments[index];
            if (source != null) {
                for (var key in source) {
                    if (Object.prototype.hasOwnProperty.call(source, key)) {
                        target[key] = source[key];
                    }
                }
            }
        }
        return target;
    };
}
function runHttpQueryWrapper(options, request, reply) {
    return apollo_server_core_1.runHttpQuery([request], {
        method: request.method.toUpperCase(),
        options: options,
        query: request.method === 'post' ? request.payload : request.query
    }).then(function (gqlResponse) {
        return reply(gqlResponse).type('application/json');
    }, function (error) {
        if ('HttpQueryError' !== error.name) {
            throw error;
        }
        if (true === error.isGraphQLError) {
            return reply(error.message).code(error.statusCode).type('application/json');
        }
        var err = Boom.create(error.statusCode);
        err.output.payload.message = error.message;
        if (error.headers) {
            Object.keys(error.headers).forEach(function (header) {
                err.output.headers[header] = error.headers[header];
            });
        }
        return reply(err);
    });
}
var graphqlHapi = function (server, options, next) {
    if (!options || !options.graphqlOptions) {
        throw new Error('Apollo Server requires options.');
    }
    if (arguments.length !== 3) {
        throw new Error("Apollo Server expects exactly 3 argument, got " + arguments.length);
    }
    server.route({
        method: ['GET'],
        path: options.path || '/graphql',
        vhost: options.vhost || undefined,
        config: options.route || {},
        handler: function (request, reply) { return runHttpQueryWrapper(options.graphqlOptions, request, reply); }
    });
    server.route({
        method: ['POST'],
        path: options.path || '/graphql',
        vhost: options.vhost || undefined,
        config: Object.assign({ 'payload': { 'maxBytes': 30000000 } }, options.route) || {},
        handler: function (request, reply) { return runHttpQueryWrapper(options.graphqlOptions, request, reply); }
    });
    return next();
};
exports.graphqlHapi = graphqlHapi;
graphqlHapi.attributes = {
    name: 'graphql',
    version: '0.0.1'
};
var graphiqlHapi = function (server, options, next) {
    if (!options || !options.graphiqlOptions) {
        throw new Error('Apollo Server GraphiQL requires options.');
    }
    if (arguments.length !== 3) {
        throw new Error("Apollo Server GraphiQL expects exactly 3 arguments, got " + arguments.length);
    }
    server.route({
        method: 'GET',
        path: options.path || '/graphiql',
        config: options.route || {},
        handler: function (request, reply) {
            var query = request.query;
            GraphiQL.resolveGraphiQLString(query, options.graphiqlOptions, request).then(function (graphiqlString) {
                reply(graphiqlString).header('Content-Type', 'text/html');
            }, function (error) { return reply(error); });
        }
    });
    return next();
};
exports.graphiqlHapi = graphiqlHapi;
graphiqlHapi.attributes = {
    name: 'graphiql',
    version: '0.0.1'
};
